==> nextcloud-29.0.5.tgz: nextcloud/apps/oauth2/l10n/uk.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Ваш клієнт не авторизований для підключення. Будь ласка, повідомте адміністратора вашого клієнта.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Ваша URL-адреса переспрямування має бути повною URL-адресою, наприклад: https://yourdomain.com/path",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Дозволяє авторизацію OAuth2, яка підтримується іншими вебзастосунками.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "Застосунок OAuth2 дозволяє адміністраторам налаштувати вбудований процес авторизації, який дозволить використовувати сумісний з OAuth2 метод авторизації для сторонніз вебзастосунків.",
    "OAuth 2.0 clients" : "Клієнти OAuth 2.0",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 дозволяє зовнішнім службам запитувати доступ до {instanceName}.",
    "Name" : "Ім'я",
    "Redirection URI" : "URI перенаправлення",
    "Client Identifier" : "Ідентифікатор клієнта",
    "Secret key" : "Пароль",
    "Delete client" : "Вилучити клієнта",
    "Add client" : "Додати клієнта",
    "Add" : "Додати",
    "Delete" : "Вилучити",
    "Show client secret" : "Показати ключ клієнта",
    "Hide client secret" : "Приховати ключ клієнта"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-30.0.13.tgz: nextcloud/apps/oauth2/l10n/uk.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Ваш клієнт не авторизований для підключення. Будь ласка, повідомте адміністратора вашого клієнта.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Ваша URL-адреса переспрямування має бути повною URL-адресою, наприклад: https://yourdomain.com/path",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Дозволяє авторизацію OAuth2, яка підтримується іншими вебзастосунками.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "Застосунок OAuth2 дозволяє адміністраторам налаштувати вбудований процес авторизації, який дозволить використовувати сумісний з OAuth2 метод авторизації для сторонніз вебзастосунків.",
    "OAuth 2.0 clients" : "Клієнти OAuth 2.0",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 дозволяє зовнішнім службам запитувати доступ до {instanceName}.",
    "Name" : "Ім'я",
    "Redirection URI" : "URI перенаправлення",
    "Client Identifier" : "Ідентифікатор клієнта",
    "Secret key" : "Пароль",
    "Delete client" : "Вилучити клієнта",
    "Add client" : "Додати клієнта",
    "Add" : "Додати",
    "Show client secret" : "Показати ключ клієнта",
    "Hide client secret" : "Приховати ключ клієнта",
    "Delete" : "Вилучити"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
